#!/bin/sh
# Make the distribution archive
# @Date: 2001.04.07
# ./dist.sh "cvs parameters"

if [ "$2" != "MANUALEXECUTIONFORBIDDEN" ]; then
	echo "error, this script may only be executed by dist (/home/scripts/dist.sh)"
	exit
fi

if [ -f /tmp/disting ]; then
	echo dist is already running, or has been aborted incorrectly:
	ls -l /tmp/disting
	echo -n "continue? (y) "
	read answer
	if [ "$answer" != "y" ]; then
		exit
	fi
fi

touch /tmp/disting
chmod 777 /tmp/disting

# CVSBRANCH
if ( test "$1" != "node_3_stable" && test "$1" != "head" && test "$1" != "node_35_stable" && test "$1" != "node_35_test" && test "$1" != "node_36_stable" && test "$1" != "node_4_stable"&& test "$1" != "node_41_stable" && test "$1" != "node_head" && test 0 == `expr "$1" : "node_"` ); then
	tmp=`eval echo \\$$branch`
	echo "usage: ./dist.sh [node_3_stable OR node_head OR node_35_stable OR node_35_test OR node_36_stable OR node_4_stable ]"
	rm -f /tmp/disting
	exit
fi

# function for cleaning old builds.
function cleanold {
# clean old builds
echo "removing old builds, keeping 1 every 30 days..."
i=1
while [ "$i" != 36 ]
do
	min=$((30*$i))
	max=$((30*$i+30+1))
	list=`find /home/releases/update -type f -mtime +$min -mtime -$max -name "$1"`
	x=0
	for ls in $list; do
		if [ "$x" != "0" ]; then
			rm -f $ls
		fi
		x=$(($x+1))
	done
	i=$(($i+1))
done
}

# build
DATE=`date +%Y%m%d`
BUILD=$DATE
NAME=Node
#if ( test "$1" == "" ); then
#  CVSBRANCH="stable"
#else
	CVSBRANCH=$1
#fi

# Backup dir
BACKUP=/home/releases
MYTMP=$TMP
TMP=$BACKUP/tmp
MYPWD=$PWD

# dist tools dir
DISTTOOLS=dev.dist
IONENCODER=/home/scripts/ioncube_encoder/ioncube_encoder

cd $BACKUP/tmp/cvs

rm -Rf $BACKUP/tmp/cvs/*
rm -Rf $BACKUP/tmp/cvs/.node

read -e -p "enter .Node NODE_LICENSE_SECRET: " secret
hash=`echo "$secret" | md5sum`
if [ "x$hash" != "xa5567f564ed30600d63eaf07ab8d9500  -" ]; then
	echo "invalid secret!"
	exit 1
fi

source /home/scripts/include/versions.inc

# 3 stable
if [ "x$1" == "xnode_3_stable" ]; then
	VERSION="3"
	CVSBRANCH="stable"
	MODULES=$node_3_stable
fi

# 3.5 stable
if [ "x$1" == "xnode_35_stable" ]; then
  	VERSION="3.5"
	CVSBRANCH="stable"
	MODULES=$node_35_stable
fi

#3.5.99
if [ "x$1" == "xnode_35_test" ]; then
  VERSION="3.5";
  CVSBRANCH="test";
  MODULES=$node_35_test
fi

# head
if [ "x$1" == "xnode_head" ]; then
  #VERSION="3.5.0.99"
  VERSION="4.0"
  CVSBRANCH="head"
  MODULES=$node_head
fi

# 36 stable
if [ "x$1" == "xnode_36_stable" ]; then
  VERSION="3.6"
  CVSBRANCH="stable"
  MODULES=$node_36_stable
fi

# 3.7 stable !!)
if [ "x$1" == "xnode_37_stable" ]; then
  VERSION="3.7"
  CVSBRANCH="stable"
  MODULES=$node_37_stable
fi

# 401 stable
if [ "x$1" == "xnode_401_stable" ]; then
  VERSION="4.0.1"
  CVSBRANCH="stable"
  MODULES=$node_401_stable
fi

# java head 31 stable, 32 stable
if ( test "x$1" == "xportalnode_head" || test "x$1" == "xportalnode_31_stable" || test "$1" == "portalnode_32_stable" || test "$1" == "portalnode_33_stable" || test "$1" == "portalnode_current" || test 0 != `expr "$1" : "portalnode_3"` ); then
	VERSION=4
	CVSBRANCH="head"
	if  ( [ "x$1" == "xportalnode_head" ] || test "$1" == "portalnode_current" || test 0 != `expr "$1" : "portalnode_3"` || test "$1" == "$portalnode_32_current_alias" || test "$1" == "$portalnode_33_current_alias" ) ; then
		MODULES=$portalnode_head
		CVSBRANCH=$1
		if ( test $CVSBRANCH == "portalnode_current" || test $CVSBRANCH == "$portalnode_32_current_alias" || test $CVSBRANCH == "portalnode_32_current" ) ; then
			CVSBRANCH="portalnode_32_current"
			tmp=`eval echo \\$$CVSBRANCH`
			CVSBRANCH=`echo $tmp`
		fi
		if ( test $CVSBRANCH == "$portalnode_33_current_alias") ; then
			CVSBRANCH="portalnode_33_current"
			tmp=`eval echo \\$$CVSBRANCH`
			CVSBRANCH=`echo $tmp`
		fi
		tmp=`eval echo \\$$CVSBRANCH`
		MODULES=`echo $tmp`
		/home/scripts/pn/execute_pn_dist.sh "$CVSBRANCH" "$MODULES" "$3" "$4"
        	rm -f /tmp/disting
		exit
	fi
	if [ "$1" == "portalnode_32_stable" ]; then
		MODULES=$portalnode_32_stable
		/home/scripts/pn/execute_pn_dist.sh "$1" "$MODULES" "$3" "$4"
		rm -f /tmp/disting
		exit
	fi
	if [ "$1" == "portalnode_33_stable" ]; then
		MODULES=$portalnode_33_stable
		/home/scripts/pn/execute_pn_dist.sh "$1" "$MODULES" "$3" "$4"
		rm -f /tmp/disting
		exit
	fi
	if [ "x$1" == "xportalnode_31_stable" ]; then
		MODULES=$portalnode_31_stable
	fi

	# prepare
	rm -Rf $MYTMP/"$1"_build
	mkdir -p $MYTMP/"$1"_build
	cd $MYTMP/"$1"_build
	if [ "$?" != "0" ]; then
		exit
	fi
	echo "checking out cvs $MODULES..."

	# prep tags
	for module in $MODULES
	do
		mod=`echo $module | sed "s/:.*$//"`
		tag=`echo $module | sed "s/^.*://"`
		if [ "$tag" != "$mod" ]; then
			tag="-r $tag"
		fi
		if [ "$tag" == "$mod" ]; then
			tag=""
		fi
		cvs -q checkout -P $tag $mod >> $MYTMP/$1.cvs.log
	done

	# checkout and show only errors
	#cvs -q checkout $MODULES > $MYTMP/$1.cvs.log

	# build
	echo "building..."
	cd $MYTMP/"$1"_build/java.portal.node.meta
	echo "catalina.home=/opt/jakarta-tomcat-5.0.16" > $MYTMP/"$1"_build/build.properties
	ant dist
	if [ "$?" != "0" ]; then
		exit
	fi
	if [ "$1" == "portalnode_31_stable" ]; then
		mv /home/releases/update/$1/build_* /home/releases/update/$1/old
		mv ../dist/*.war /home/releases/update/$1
	else 
		b=`cat ../output/BUILD`
		rm -Rf /home/releases/update/$1/build_*
		rm -Rf /home/releases/update/$1/portal-package
		mkdir -p /home/releases/update/$1/build_$b
		mv ../output/* /home/releases/update/$1/build_$b
		rm -f /home/releases/update/$1/current
		ln -s /home/releases/update/$1/build_$b /home/releases/update/$1/current
		mkdir /home/releases/update/$1/portal-package
		cp /home/releases/update/$1/current/portal/demo/Portal.Node.war /home/releases/update/$1/portal-package
		cp /home/releases/update/$1/current/gentics-portalnode-3-sharedlibs.zip /home/releases/update/$1/portal-package

		# prep sdk cd
		/home/scripts/sdk/buildcd.sh

		chgrp -R cvs_pub /home/releases/update/$1/*
		chmod -R 777 /home/releases/update/$1/*
	fi
	# cleanup
	echo "cleaning up..."
	rm -Rf $MYTMP/"$1"_build
	rm -f $MYTMP/$1.cvs.log
	rm -f /tmp/disting
	cleanold "Portal.Node*.war"
	echo "done, fetch PN from /home/releases/update/$1/ and SDK from /home/releases/pn3sdk..."
	echo "farewell $USER."
	exit
fi


cleanold "Node_V$VERSION-$CVSBRANCH*"

DIST=$NAME"_"V$VERSION"-"$CVSBRANCH"-"$BUILD

echo

echo "Checking for modules: "
for module in $MODULES 
do
  branch=`echo $module | sed s/^.*://`
  if [ "x$CVSBRANCH" == "xhead" ]; then
	  	branch=""
  fi
  module=`echo $module | sed s/:.*//`
  if [ "$branch" == "$module" ]; then
  	branch=""
  fi
  while :; do
    echo -n "Do you want to dist module $module y(es) n(o)? "
	if ( test "x$CVSBRANCH" = "xstable" || test "x$CVSBRANCH" = "xtest" || test "x$CVSBRANCH" = "xhead" ); then
		yn=y
		echo
	else
		read yn
	fi
    case "$yn" in
    n*)
      break 1
    ;;
    y*)
	echo -n "Enter CVS branch to checkout (leave empty for trunk): "
	if ( test "x$CVSBRANCH" = "xstable" || test "x$CVSBRANCH" = "xtest" || test "x$CVSBRANCH" = "xhead" ); then
		brach="$branch"
		echo
	else
		read branch
	fi
	if [ "x$branch" != "x" ]; then
		branch="-r $branch "
	fi
	echo "cvs checkout $branch$module"
	cvs checkout $branch$module > $BACKUP/log/cvsdist.log 2>&1
      break 1
      ;;
    esac
  done
done

#move modules
mkdir .node/modules
mv -f system.node .node/modules/system
mv -f content.node .node/modules/content
mv -f tracking.node .node/modules/tracking
mv -f portal.node .node/modules/portal
mv -f business.node .node/modules/business
mv -f schedule.node .node/modules/schedule
#move skeleton
mv -f skeleton .node/skeleton
#move xnl
mv -f xnl .node/xnl
#portalnode frontend
mv -f portalnode .node

if [ "x$hash" != "x" ]; then
	perl -pi -e "s/\/\*_SECRET_NODE_LICENSE_KEY_START_//" .node/modules/system/core/home.php
	perl -pi -e "s/_SECRET_NODE_LICENSE_KEY_END_\*\///" .node/modules/system/core/home.php
	perl -pi -e "s/_SECRET_NODE_LICENSE_KEY_/$secret/" .node/modules/system/core/home.php
fi

# dist.sh is supposed to be in dev.dist/
chmod -R 770 .node
chmod 755 .node/changelog.php
chown -R $USER.gentics .node
cd .node

# get call for do's
source /Node/bin/env.sh
SH_PHP="./sh.php --no-owner CONFIGFILE=$PWD/config.php"

echo 
echo "+---------------------------+"
echo "| Archive Builder for .Node |"
echo "+---------------------------+"
echo 

# Check for open files
echo -n "Checking for .swp files ..."
SWP=`find $PWD/ -follow -regex '.*swp'`
if [ ! -z "$SWP" ]; then
  echo
  echo "Please remove .swp files"
  find $PWD/ -follow -regex '.*swp'
  while :; do
    echo -n "Do you want to continue? y(es) n(o) r(emove)? "
    read c
    case "$c" in
    y*)
      break 1
    ;;
    n*)
      exit 1
    ;;
    r*)
      find $PWD/ -follow -regex '.*swp' -exec rm {} \;
      break 1 
    ;;
    esac
  done
#  exit 0
else
  echo " done."
fi

# check for tar.gz..
echo -n "Checking for .tar.gz ..."
TGZ=`find $PWD/ -iname "*\.tar\.gz" -type f -maxdepth 1`
if [ ! -z "$TGZ" ]; then
  echo " found."
  find $PWD/ -iname "*\.tar\.gz" -type f -maxdepth 1
  while :; do
    echo -n "Do you want to continue? y(es) n(o) r(emove)? "
    read c
    case "$c" in
    y*)
      break 1
    ;;
    n*)
      exit 1
    ;;
    r*)
      find $PWD/ -iname "*\.tar\.gz" -type f -maxdepth 1 -exec rm {} \;
      break 1
    ;;
    esac
  done
else
  echo " done."
fi

# ask for pcs encoding
while :; do
  echo -n "Do you want to encode .Node? y(es) n(o) p(cs) i(oncube)? "
  if [ "x$CVSBRANCH" == "xstable" ]; then
        if [ "x$3" == "x--forcenoencode" ]; then
	    pcs=n
	else
	    pcs=y
	fi
    echo
  else
	read pcs
  fi
  case "$pcs" in
  p*)
    ENCODE=true
    break 1
    ;;
  i*)
    ENCODE="ion"
    break 1
    ;;
  y*)
    if [ "$VERSION" == "3.6" ]; then
    	ENCODE=true
    else 
    	ENCODE="ion"
    fi
    break 1
  ;;
  n*)
    break 1
    ;;
  esac
done

# Check tmp dir if
if [ ! -e $BACKUP ]; then
  mkdir $BACKUP
fi
if [ ! -e $TMP ]; then
  mkdir $TMP
fi
if [ -e $BACKUP/update/$DIST.tar.gz ]; then
  for sub_version in a b c d e f g h i j k l m n o p q r s t u v w x y z
  do
    if [ ! -e $BACKUP/update/$DIST$sub_version.tar.gz ]; then
      DIST=$DIST$sub_version
      break
    fi
  done
fi
BUILD="V$VERSION-$CVSBRANCH-$BUILD$sub_version"
echo 
echo "Build is $BUILD."
echo "----------------------------"
export BUILD

# Create the dic file before build
echo -n "Dating up Dic file ..."
mkdir -p $PWD/languages
$SH_PHP do=200
echo " done."

# Remove the existing tmp dir if exists
if [ -e $TMP/$DIST ] && [ "$TMP" != "" ] && [ "$DIST" != "" ]; then 
  echo -n "Clean up \"$TMP/$DIST\" ..."
  rm -Rf $TMP/$DIST
  echo " done."
fi

# Update sql datafile
echo -n "Updating sql datafile... "
$SH_PHP do=201
echo " done."

# Coping the current dir to temp 
echo -n "Cloning \"$PWD\" to \"$TMP/$DIST\" ..."
cp -R $PWD $TMP/$DIST
echo " done."

# create changelog directory
mkdir "$TMP/$DIST/CHANGELOG"

echo " done."

# Do some settings...
echo -n "Set DIC_SOURCE to file ..."
$SH_PHP do=30 dir=$TMP/$DIST/include filename=global.inc.php var=DIC_SOURCE value=file
echo " done."

echo -n "Turning off DEBUG:"
echo -n " perm"
$SH_PHP do=30 dir=$TMP/$DIST/include filename=global.inc.php var=DEBUG[\"perm\"] value=false
echo -n " tree"
$SH_PHP do=30 dir=$TMP/$DIST/include filename=global.inc.php var=DEBUG[\"tree\"] value=false
echo -n " item_list"
$SH_PHP do=30 dir=$TMP/$DIST/include filename=global.inc.php var=DEBUG[\"item_list\"] value=false
echo -n " halt"
$SH_PHP do=30 dir=$TMP/$DIST/include filename=global.inc.php var=DEBUG[\"halt\"] value=false
echo -n " bug"
$SH_PHP do=30 dir=$TMP/$DIST/include filename=global.inc.php var=DEBUG[\"bug\"] value=false
echo -n " log_all"
$SH_PHP do=30 dir=$TMP/$DIST/include filename=global.inc.php var=DEBUG[\"log_all\"] value=false
echo -n " permbit"
$SH_PHP do=30 dir=$TMP/$DIST/include filename=global.inc.php var=DEBUG[\"permbit\"] value=false
echo -n " echo"
$SH_PHP do=30 dir=$TMP/$DIST/include filename=global.inc.php var=DEBUG[\"echo\"] value=false
echo -n " session"
$SH_PHP do=30 dir=$TMP/$DIST/include filename=global.inc.php var=DEBUG[\"session\"] value=false
echo -n " db"
$SH_PHP do=30 dir=$TMP/$DIST/include filename=global.inc.php var=DEBUG[\"db\"] value=false
echo -n " time"
$SH_PHP do=30 dir=$TMP/$DIST/include filename=global.inc.php var=DEBUG[\"time\"] value=false
echo -n " php"
$SH_PHP do=30 dir=$TMP/$DIST/include filename=global.inc.php var=DEBUG[\"php\"] value=false
echo -n " log_query"
$SH_PHP do=30 dir=$TMP/$DIST/include filename=global.inc.php var=DEBUG[\"log_query\"] value=false
echo -n " tag_save"
$SH_PHP do=30 dir=$TMP/$DIST/include filename=global.inc.php var=DEBUG[\"tag_save\"] value=false
echo " done."

# just for colors in vi: "

#scripts for COMMAND and SCRIPT changelogs
echo -n "Copying scripts..."
for module in `ls $TMP/$DIST/modules`
do
  mkdir -p "$TMP/$DIST/CHANGELOG/scripts/$module/"
  if [ -d "$TMP/$DIST/modules/$module/dev.doc/scripts/" ]; then
	echo -n " $module"
  	cp -a "$TMP/$DIST/modules/$module/dev.doc/scripts/"* "$TMP/$DIST/CHANGELOG/scripts/$module/"
  fi
done
module="$DIST"
mkdir -p "$TMP/$DIST/CHANGELOG/scripts/$module/"
if [ -d "$TMP/$DIST/dev.doc/scripts/" ]; then
	echo -n " $module"
  	cp -a "$TMP/$DIST/dev.doc/scripts/"* "$TMP/$DIST/CHANGELOG/scripts/$module/"
fi
echo " ...done."
 
#copy CHANGELOGS
echo -n "Copying CHANGELOGs..."
find "$TMP/$DIST" -name "CHANGELOG" -type f -exec "$MYPWD/changelog_dist.sh" "{}" "$TMP/$DIST/CHANGELOG" \;
echo "done."

# update tagmap
echo -n "Updating tagmap file..."
$SH_PHP do=30 dir=./ filename=config.php var=LOAD_MODULE[\"content\"] value=true
$SH_PHP do=16671 > $TMP/$DIST/CHANGELOG/scripts/content/tagmap.sql

# Remove or clean up sub dirs
echo -n "Deleting confidential directories: "
# Remove
echo -n " system"
if [ "$ENCODE" == "true" ]; then
  mv "$TMP/$DIST/dev.dist/pcs_encode" "$TMP/$DIST"
fi

#remove all dev.*
echo -n " dev.*"
find "$TMP/$DIST" -name "dev.*" -exec rm -Rf "{}" \; 2>&1 | grep -v "dev\..* No such file or directory"
rm -Rf $TMP/$DIST/doc
#remove all CVS
echo -n " CVS"
find "$TMP/$DIST" -name CVS -exec rm -rf "{}" \; > /dev/null 2>&1
echo " done."

   

# Create archive
echo -n "Creating archive ..."
# Change build
echo -n "Changing build version to $BUILD ..."
$SH_PHP do=30 dir=$TMP/$DIST/include filename=global.inc.php var=BUILD value=$BUILD-$CVSBRANCH
echo "$BUILD" > $TMP/$DIST/BUILD
echo " done."

# Preparing install 
echo -n "Preparing install script..."
$SH_PHP do=30 dir=$TMP/$DIST filename=install.sh var_type=sh var=VERSION value=$BUILD
$SH_PHP do=30 dir=$TMP/$DIST filename=install.sh var_type=sh var=INST_NAME value=$NAME
echo " done."

echo -n "Switching off modules: "
for module in `ls $TMP/$DIST/modules`
do
  if [ $module != "system" ]; then
    echo -n " $module"
    $SH_PHP do=30 dir=$TMP/$DIST filename=config.php var=LOAD_MODULE[\"$module\"] value=false
  fi
done
echo " done."

# "
if [ "$ENCODE" == "ion" ]; then
  echo -n "IonCube Encoding .Node ..."

  IONOPTIONS="--without-loader-check --optimize max --binary --exclude config.php --exclude sh.php --exclude xnl/ --exclude portalnode"
  #IONOPTIONS=--project-file=ioncube.proj --passphrase=$secret
  
  rm -rf $TMP/$DIST-ion
  $IONENCODER $IONOPTIONS -o $TMP/$DIST-ion $TMP/$DIST
  if [ "$?" != "0" ]; then
    echo "ERROR: ioncube encoding failed!"
    exit $? 
  fi
  if [ ! -e $TMP/$DIST-ion ]; then
    echo "ERROR: ioncube encoding failed!"
    exit -1
  fi
  rm -rf $TMP/$DIST
  mv $TMP/$DIST-ion $TMP/$DIST
  
  echo "done."
elif [ ! -z $ENCODE ]; then
  echo -n "PCS Encoding .Node ..."
  mv "$TMP/$DIST/config.php" "$TMP"
  mv "$TMP/$DIST/sh.php" "$TMP"
  #mv $TMP/$DIST/include/modules.inc.php $TMP
  #mv $TMP/$DIST/include/global.inc.php $TMP
  for module in `ls $TMP/$DIST/modules`
  do
    if [ -e "$TMP/$DIST/modules/$module/include/config.php" ]; then
      mkdir "$TMP/$module"
      mv "$TMP/$DIST/modules/$module/include/config.php" "$TMP/$module"
    fi
  done
  find "$TMP/$DIST" | grep -v portalnode | grep -v xnl | grep php$ | "$TMP/$DIST/pcs_encode"
  echo "find $TMP/$DIST | grep -v portalnode | grep -v xnl | grep php$ | $TMP/$DIST/pcs_encode"
  #mv $TMP/modules.inc.php $TMP/$DIST/include/
  #mv $TMP/global.inc.php $TMP/$DIST/include/
  mv "$TMP/config.php" "$TMP/$DIST/"
  mv "$TMP/sh.php" "$TMP/$DIST/"
  for module in `ls $TMP/$DIST/modules`
  do
    if [ -e $TMP/$module ]; then
      mv "$TMP/$module/config.php" "$TMP/$DIST/modules/$module/include"
      rmdir "$TMP/$module"
    fi
  done
  rm "$TMP/$DIST/pcs_encode"
  echo " done."
else 
  echo "NO PCS Encoding!"
fi

chmod 755 "$TMP/$DIST/changelog.php"

echo -n "Creating archive $TMP/$DIST.tar.gz..."
tar czf "$TMP/$DIST.tar.gz" --directory="$TMP" "$DIST"
echo " done."

# Creating backup of Distribution
echo -n "Creating backup of Distribution ..."
cp "$TMP/$DIST.tar.gz" "$BACKUP/update"
echo " done."

# Building CNPortlet app
echo "Building CNPortlet application ..."
/home/scripts/cn/buildcnportletapp.sh $1
mv /var/tmp/cnbuild $BACKUP/update/CNPortletapp.$DIST
echo "Done."

# Remove temp dir
echo -n "Cleaning up temporary files ..."
rm -R "$TMP/$DIST"
mv "$TMP/$DIST.tar.gz" .
rm -f "$TMP/Node*"
rm -Rf "$BACKUP/tmp/cvs/.node"
rm -Rf "$BACKUP/tmp/cvs/*"
echo " done."

# allow not encoded stable releases
#if [ "$ENCODE" != "" ]; then
  echo -n "Is this a $CVSBRANCH release? (y/n) "
  DONE=0
  RELEASE=0
  while [ "$DONE" != "1" ]; do
	  DONE=1
	  read answer 
	  if [ "$answer" == "y" ]; then
		  echo "This is a $CVSBRANCH release. Copying dist to $CVSBRANCH directory..."
		  rm -Rf "$BACKUP"/"V"${VERSION}_${CVSBRANCH}_update/*
		  cp -a "$BACKUP/update/$DIST.tar.gz" "$BACKUP/V${VERSION}_${CVSBRANCH}_update"
		  cp -a "$BACKUP/update/CNPortletapp.$DIST" "$BACKUP/V${VERSION}_${CVSBRANCH}_update/"
		  RELEASE=1
	  elif [ "$answer" == "n" ]; then
		  echo "Unstable. Do some bugfixing. Go."
	  else
		  echo -n "Invalid input. Try again "
		  sleep 1
		  echo -n "(y/n) "
		  DONE=0	
	  fi
  done
#fi
echo 
echo "+------------------------------+"
echo "+ Congratulation, you're done! +"
echo "+------------------------------+"
if [ "$RELEASE" == "1" ]; then
	echo "You can now start: nodeupdate <server name>"
fi
# Finish

rm -f /tmp/disting

exit 0
